lilypondnametools.LilyPondSettingNameManager
============================================

.. abjad-lineage:: abjad.tools.lilypondnametools.LilyPondSettingNameManager.LilyPondSettingNameManager

.. autoclass:: abjad.tools.lilypondnametools.LilyPondSettingNameManager.LilyPondSettingNameManager

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondnametools.LilyPondSettingNameManager.LilyPondSettingNameManager.__eq__
      ~abjad.tools.lilypondnametools.LilyPondSettingNameManager.LilyPondSettingNameManager.__format__
      ~abjad.tools.lilypondnametools.LilyPondSettingNameManager.LilyPondSettingNameManager.__getattr__
      ~abjad.tools.lilypondnametools.LilyPondSettingNameManager.LilyPondSettingNameManager.__ne__
      ~abjad.tools.lilypondnametools.LilyPondSettingNameManager.LilyPondSettingNameManager.__repr__

Bases
-----

- :py:class:`lilypondnametools.LilyPondNameManager <abjad.tools.lilypondnametools.LilyPondNameManager.LilyPondNameManager>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Special methods
---------------

.. automethod:: abjad.tools.lilypondnametools.LilyPondSettingNameManager.LilyPondSettingNameManager.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondnametools.LilyPondSettingNameManager.LilyPondSettingNameManager.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondnametools.LilyPondSettingNameManager.LilyPondSettingNameManager.__getattr__
   :noindex:

.. automethod:: abjad.tools.lilypondnametools.LilyPondSettingNameManager.LilyPondSettingNameManager.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondnametools.LilyPondSettingNameManager.LilyPondSettingNameManager.__repr__
   :noindex:
